import React from 'react';
export interface Settings {
    /**
     * Rotation of the book, in degrees.
     */
    rotate: number;
    /**
     * Rotation of the book on hover, in degrees.
     */
    rotateHover: number;
    /**
     * Perspective value. 600 seems to be a realistic value.
     */
    perspective: number;
    /**
     * Duration of rotate animation, in milliseconds.
     */
    transitionDuration: number;
    /**
     * Radius of right corners, in pixels.
     */
    radius: number;
    /**
     * Book thickness, in pixels.
     */
    thickness: number;
    /**
     * Color of the inside of back cover.
     */
    bgColor: string;
    /**
     * Width of the book, in pixels.
     */
    width: number;
    /**
     * Height of the book, in pixels.
     */
    height: number;
    /**
     * Offset between the pages and the cover size, in pixels.
     */
    pagesOffset: number;
}
export interface Props extends Settings {
    children: React.ReactNode;
}
/**
 * `BookCover` is the component you can use to display an animated 3D version of your book cover.
 *
 * ## Install
 *
 * ```bash
 * yarn add book-cover-3d
 * # Or with NPM:
 * npm i --save book-cover-3d
 * ```
 *
 * ## Usage
 *
 * The only required parameter is the URL of the image you want to display as a cover.
 *
 * ```jsx
 * import { BookCover } from 'book-cover-3d'
 *
 * <BookCover imageUrl="https://3dbook.xyz/demo-book.png" />
 * ```
 */
export declare const BookCover: ({ children, rotate, rotateHover, perspective, transitionDuration, radius, thickness, bgColor, width, height, pagesOffset, }: Props) => JSX.Element;
export declare const getCssForSettings: (uniqueId: string, settings: Settings) => string;
